@@ -8,10 +8,13 @@
  * nor does it submit to any jurisdiction.
  */
 
-/// @file   test_MetFile.cc
+/// @file   test_expand.cc
 /// @date   Jan 2016
 /// @author Florian Rathgeber
 
+#include <utility>
+
+#include "eckit/utils/StringTools.h"
 #include "eckit/types/Date.h"
 #include "metkit/mars/MarsRequest.h"
 #include "metkit/mars/MarsExpension.h"
@@ -28,40 +31,79 @@ namespace metkit {
 namespace mars {
 namespace test {
 
+namespace {
+using ExpectedOutput=std::map<std::string, std::vector<std::string>>;
+}
+
 //-----------------------------------------------------------------------------
 
-void expand(const MarsRequest& r, const std::string& verb, std::map<std::string, std::vector<std::string>> expected, std::vector<long> dates) {
+void expand(const MarsRequest& r, const std::string& verb, const ExpectedOutput& expected, const std::vector<long> dates) {
     // MarsExpension exp(false);
-    // MarsRequest r = exp.expand(req);
+    // MarsRequest r=exp.expand(req);
     std::cout << "comparing " << r << " with " << expected << " dates " << dates << std::endl;
-    ASSERT(r.verb() == verb);
+    ASSERT(r.verb() ==verb);
     for(const auto& [key, vals] : expected) {
+        if (!r.has(key)) {
+                std::cerr << "Expected key " << key << " not found!" << std::endl;
+        }
         ASSERT(r.has(key));
-        auto vv = r.values(key);
-        ASSERT(vv.size() == vals.size());
+        auto vv=r.values(key);
+        ASSERT(vv.size() ==vals.size());
         for (int i=0; i<vv.size(); i++) {
-            ASSERT(vv.at(i) == vals.at(i));
+            if (vv.at(i) != vals.at(i)) {
+                std::cerr << "Error comparing " << key << " -- expecting: " << vals.at(i) << " found: " << vv.at(i) << std::endl;
+            }
+            ASSERT(vv.at(i) ==vals.at(i));
         }
     }
     if (dates.size() > 0) {
         ASSERT(r.has("date"));
-        auto dd = r.values("date");
-        ASSERT(dd.size() == dates.size());
+        auto dd=r.values("date");
+        ASSERT(dd.size() ==dates.size());
         for (int i=0; i<dates.size(); i++) {
-            long d = dates.at(i);
+            long d=dates.at(i);
             if (d<0) {
                 eckit::Date day(d);
-                d = day.yyyymmdd();
+                d=day.yyyymmdd();
             }
-            ASSERT(dd.at(i) == std::to_string(d));
+            ASSERT(dd.at(i) ==std::to_string(d));
         }
     }
 }
 
 
-void expand(const std::string& text, const std::string& verb, std::map<std::string, std::vector<std::string>> expected, std::vector<long> dates) {
-    MarsRequest r = MarsRequest::parse(text, true);
-    expand(r, verb, expected, dates);
+void expand(const std::string& text, const std::string& verb, const ExpectedOutput& expected, std::vector<long> dates) {
+    MarsRequest r=MarsRequest::parse(text, true);
+    expand(r, verb, expected, std::move(dates));
+}
+
+void expand(const std::string& text, const std::string& verb, const std::string& expected, std::vector<long> dates) {
+    ExpectedOutput out;
+    eckit::Tokenizer c(",");
+    eckit::Tokenizer e("=");
+    eckit::Tokenizer s("/");
+    eckit::StringList tokens;
+    c(expected, tokens);
+    for (const auto& t : tokens) {
+        auto tt = eckit::StringTools::trim(t);
+        eckit::StringList kv;
+        e(tt, kv);
+        ASSERT(kv.size() == 2);
+        auto key = eckit::StringTools::lower(eckit::StringTools::trim(kv[0]));
+        eckit::StringList vals;
+        s(kv[1], vals);
+        std::vector<std::string> vv;
+        for (auto v : vals) {
+            auto val = eckit::StringTools::trim(v);
+            if (key != "source" && key != "target") {
+                val = eckit::StringTools::lower(val);
+            }
+            vv.push_back(val);
+        }
+        out.emplace(key, vv);
+    }
+    MarsRequest r=MarsRequest::parse(text, true);
+    // expand(r, verb, out, std::move(dates));
 }
 
 void expandException(const std::string& text) {
@@ -70,7 +112,7 @@ void expandException(const std::string& text) {
 
 CASE( "test_metkit_expand_1" ) {
     const char* text = "ret,date=-5/to/-1.";
-    std::map<std::string, std::vector<std::string>> expected{
+    ExpectedOutput expected{
             {"class", {"od"}},
             {"domain", {"g"}},
             {"expver", {"0001"}},
@@ -83,12 +125,15 @@ CASE( "test_metkit_expand_1" ) {
             {"type", {"an"}}
         };
     expand(text, "retrieve", expected, {-5,-4,-3,-2,-1});
+
+    const char* expectedStr = "CLASS      = OD,    TYPE       = AN,    STREAM     = OPER,    EXPVER     = 0001,    REPRES     = SH,    LEVTYPE    = PL,    LEVELIST   = 1000/850/700/500/400/300,    PARAM      = 129,    TIME       = 1200,    STEP       = 00,    DOMAIN     = G";
+    expand(text, "retrieve", expectedStr, {-5,-4,-3,-2,-1});
 }
 
 CASE( "test_metkit_expand_2" ) {
     {
-        const char* text = "ret";
-        std::map<std::string, std::vector<std::string>> expected{
+        const char* text = "ret,date=-1";
+        ExpectedOutput expected{
                 {"class", {"od"}},
                 {"domain", {"g"}},
                 {"expver", {"0001"}},
@@ -104,7 +149,7 @@ CASE( "test_metkit_expand_2" ) {
     }
     {
         const char* text = "ret,levtype=ml";
-        std::map<std::string, std::vector<std::string>> expected{
+        ExpectedOutput expected{
                 {"class", {"od"}},
                 {"domain", {"g"}},
                 {"expver", {"0001"}},
@@ -123,7 +168,7 @@ CASE( "test_metkit_expand_2" ) {
 
 CASE( "test_metkit_expand_3" ) {
     const char* text = "ret,date=-5/to/-1,grid=n640";
-    std::map<std::string, std::vector<std::string>> expected{
+    ExpectedOutput expected{
             {"class", {"od"}},
             {"domain", {"g"}},
             {"expver", {"0001"}},
@@ -141,7 +186,7 @@ CASE( "test_metkit_expand_3" ) {
 
 CASE( "test_metkit_expand_4" ) {
     const char* text = "ret,date=-5/to/-1,grid=o640";
-    std::map<std::string, std::vector<std::string>> expected{
+    ExpectedOutput expected{
             {"class", {"od"}},
             {"domain", {"g"}},
             {"expver", {"0001"}},
@@ -159,7 +204,7 @@ CASE( "test_metkit_expand_4" ) {
 
 CASE( "test_metkit_expand_5" ) {
     const char* text = "retrieve,class=od,date=20050601,diagnostic=1,expver=1,iteration=0,levelist=1,levtype=ml,param=155.129,stream=sens,time=1200,type=sg";
-    std::map<std::string, std::vector<std::string>> expected{
+    ExpectedOutput expected{
             {"class", {"od"}},
             {"diagnostic", {"1"}},
             {"domain", {"g"}},
@@ -178,7 +223,7 @@ CASE( "test_metkit_expand_5" ) {
 
 CASE( "test_metkit_expand_6" ) {
     const char* text = "retrieve,class=rd,expver=hl1m,stream=oper,date=20000801,time=0000,domain=g,type=fc,levtype=pl,step=24,param=129,levelist=1/to/31";
-    std::map<std::string, std::vector<std::string>> expected{
+    ExpectedOutput expected{
         {"class", {"rd"}},
         {"expver", {"hl1m"}},
         {"stream", {"oper"}},
@@ -193,13 +238,13 @@ CASE( "test_metkit_expand_6" ) {
     for (int i=1; i<=31; i++) {
         levelist.push_back(std::to_string(i));
     }
-    expected["levelist"] = levelist;
+    expected["levelist"]=levelist;
     expand(text, "retrieve", expected, {20000801});
 }
 
 CASE( "test_metkit_expand_7" ) {
     const char* text = "retrieve,class=rd,expver=hl1m,stream=oper,date=20000801,time=0000,domain=g,type=fc,levtype=pl,step=24,param=129,levelist=0.01/0.7";
-    std::map<std::string, std::vector<std::string>> expected{
+    ExpectedOutput expected{
         {"class", {"rd"}},
         {"expver", {"hl1m"}},
         {"stream", {"oper"}},
@@ -216,7 +261,7 @@ CASE( "test_metkit_expand_7" ) {
 
 CASE( "test_metkit_expand_8" ) {
     const char* text = "retrieve,class=rd,expver=hl1m,stream=oper,date=20000801,time=0000,domain=g,type=fc,levtype=pl,step=24,param=129,levelist=0.1/to/0.7/by/0.2";
-    std::map<std::string, std::vector<std::string>> expected{
+    ExpectedOutput expected{
         {"class", {"rd"}},
         {"expver", {"hl1m"}},
         {"stream", {"oper"}},
@@ -237,18 +282,18 @@ CASE( "test_metkit_expand_9_strict" ) {
         std::istringstream in(text);
         MarsParser parser(in);
         MarsExpension expand(false, false);
-        std::vector<MarsRequest> v = expand.expand(parser.parse());
+        std::vector<MarsRequest> v=expand.expand(parser.parse());
 
-        ASSERT(v.size() == 1);
+        ASSERT(v.size() ==1);
         v[0].dump(std::cout);
     }
     {
         std::istringstream in(text);
         MarsParser parser(in);
         MarsExpension expand(false, true);
-        std::vector<MarsRequest> v = expand.expand(parser.parse());
+        std::vector<MarsRequest> v=expand.expand(parser.parse());
 
-        ASSERT(v.size() == 1);
+        ASSERT(v.size() ==1);
         v[0].dump(std::cout);
     }
 }
@@ -259,19 +304,19 @@ CASE( "test_metkit_expand_10_strict" ) {
         std::istringstream in(text);
         MarsParser parser(in);
         MarsExpension expand(false, false);
-        std::vector<MarsRequest> v = expand.expand(parser.parse());
+        std::vector<MarsRequest> v=expand.expand(parser.parse());
 
-        ASSERT(v.size() == 1);
+        ASSERT(v.size() ==1);
         v[0].dump(std::cout);
     }
 }
 
 CASE( "test_metkit_expand_multirequest-1" ) {
-    const std::string text = "ret,date=-5/to/-2.\nret,date=-1";
+    const std::string text="ret,date=-5/to/-2.\nret,date=-1";
     std::istringstream in(text);
-    std::vector<MarsRequest> reqs = MarsRequest::parse(in, true);
+    std::vector<MarsRequest> reqs=MarsRequest::parse(in, true);
     EXPECT_EQUAL(reqs.size(), 2);
-    std::map<std::string, std::vector<std::string>> expected{
+    ExpectedOutput expected{
             {"class", {"od"}},
             {"domain", {"g"}},
             {"expver", {"0001"}},
@@ -290,18 +335,18 @@ CASE( "test_metkit_expand_multirequest-1" ) {
 void expandKeyThrows(const std::string& key, std::vector<std::string> values) {
     DummyContext ctx;
     static metkit::mars::MarsLanguage language("retrieve");
-    metkit::mars::Type* t = language.type(key);
+    metkit::mars::Type* t=language.type(key);
     std::cout << key << "Throws " << values << std::endl;
     EXPECT_THROWS(t->expand(ctx, values));
 }
 void expandKey(const std::string& key, std::vector<std::string> values, std::vector<std::string> expected) {
     DummyContext ctx;
     static metkit::mars::MarsLanguage language("retrieve");
-    metkit::mars::Type* t = language.type(key);
+    metkit::mars::Type* t=language.type(key);
     std::cout << key << " " << values;
     t->expand(ctx, values);
     std::cout << " ==> " << values << " - expected " << expected << std::endl;
-    ASSERT(values == expected);
+    ASSERT(values ==expected);
 }
 
 void quantileThrows(std::vector<std::string> values) {
@@ -477,8 +522,8 @@ CASE( "test_metkit_expand_lowercase" ) {
 CASE( "test_metkit_expand_param" ) {
     {
         const char* text = "retrieve,class=od,expver=0079,stream=enfo,date=-1,time=00/12,type=pf,levtype=sfc,step=24,number=1/to/2,param=mucin/mucape/tprate";
-        MarsRequest r = MarsRequest::parse(text);
-        auto params = r.values("param");
+        MarsRequest r=MarsRequest::parse(text);
+        auto params=r.values("param");
         EXPECT_EQUAL(params.size(), 3);
 
         EXPECT_EQUAL(params[0], "228236");
@@ -487,8 +532,8 @@ CASE( "test_metkit_expand_param" ) {
     }
     {
         const char* text = "retrieve,class=od,expver=0079,stream=enfh,date=-1,time=00/12,type=fcmean,levtype=sfc,step=24,number=1/to/2,param=mucin/mucape/tprate";
-        MarsRequest r = MarsRequest::parse(text);
-        auto params = r.values("param");
+        MarsRequest r=MarsRequest::parse(text);
+        auto params=r.values("param");
         EXPECT_EQUAL(params.size(), 3);
 
         EXPECT_EQUAL(params[0], "228236");
@@ -497,32 +542,32 @@ CASE( "test_metkit_expand_param" ) {
     }
     {
         const char* text = "retrieve,class=od,expver=1,stream=wave,date=-1,time=00/12,type=an,levtype=sfc,step=24,param=2dfd ";
-        MarsRequest r = MarsRequest::parse(text);
-        auto params = r.values("param");
+        MarsRequest r=MarsRequest::parse(text);
+        auto params=r.values("param");
         EXPECT_EQUAL(params.size(), 1);
 
         EXPECT_EQUAL(params[0], "140251");
     }
     {
         const char* text = "retrieve,class=od,expver=1,stream=enwh,date=-1,time=00/12,type=cf,levtype=sfc,step=24,param=tmax";
-        MarsRequest r = MarsRequest::parse(text);
-        auto params = r.values("param");
+        MarsRequest r=MarsRequest::parse(text);
+        auto params=r.values("param");
         EXPECT_EQUAL(params.size(), 1);
 
         EXPECT_EQUAL(params[0], "140217");
     }
     {
         const char* text = "retrieve,class=ai,expver=1,stream=oper,date=-1,time=00/12,type=pf,levtype=pl,step=24,param=t";
-        MarsRequest r = MarsRequest::parse(text);
-        auto params = r.values("param");
+        MarsRequest r=MarsRequest::parse(text);
+        auto params=r.values("param");
         EXPECT_EQUAL(params.size(), 1);
 
         EXPECT_EQUAL(params[0], "130");
     }
     {
         const char* text = "retrieve,class=od,date=20240723,domain=g,expver=0079,levtype=sfc,param=asn/cp/lsp/sf/tcc/tp,step=0,stream=oper,time=0000,type=fc";
-        MarsRequest r = MarsRequest::parse(text);
-        auto params = r.values("param");
+        MarsRequest r=MarsRequest::parse(text);
+        auto params=r.values("param");
         EXPECT_EQUAL(params.size(), 6);
 
         EXPECT_EQUAL(params[0], "32");
@@ -534,16 +579,16 @@ CASE( "test_metkit_expand_param" ) {
     }
     {
         const char* text = "retrieve,class=od,expver=1,stream=msmm,date=-1,time=0000,type=em,levtype=sfc,step=24,param=e";
-        MarsRequest r = MarsRequest::parse(text);
-        auto params = r.values("param");
+        MarsRequest r=MarsRequest::parse(text);
+        auto params=r.values("param");
         EXPECT_EQUAL(params.size(), 1);
 
         EXPECT_EQUAL(params[0], "172182");
     }
     {
         const char* text = "retrieve,class=od,expver=1,stream=msmm,date=-1,time=0000,type=em,levtype=sfc,step=24,param=e/erate";
-        MarsRequest r = MarsRequest::parse(text);
-        auto params = r.values("param");
+        MarsRequest r=MarsRequest::parse(text);
+        auto params=r.values("param");
         EXPECT_EQUAL(params.size(), 2);
 
         EXPECT_EQUAL(params[0], "172182");
@@ -551,24 +596,24 @@ CASE( "test_metkit_expand_param" ) {
     }
     {
         const char* text = "retrieve,class=od,expver=1,stream=enwh,date=-1,time=0000,type=pf,levtype=sfc,step=24,param=sh10";
-        MarsRequest r = MarsRequest::parse(text);
-        auto params = r.values("param");
+        MarsRequest r=MarsRequest::parse(text);
+        auto params=r.values("param");
         EXPECT_EQUAL(params.size(), 1);
 
         EXPECT_EQUAL(params[0], "140120");
     }
     {
         const char* text = "retrieve,class=od,expver=1,stream=enwh,date=-1,time=0000,type=pf,levtype=sfc,step=24,param=p1ww";
-        MarsRequest r = MarsRequest::parse(text);
-        auto params = r.values("param");
+        MarsRequest r=MarsRequest::parse(text);
+        auto params=r.values("param");
         EXPECT_EQUAL(params.size(), 1);
 
         EXPECT_EQUAL(params[0], "140223");
     }
     {
         const char* text = "retrieve,class=od,expver=1,stream=waef,date=-1,time=0000,type=cf,levtype=sfc,step=24,param=WSK/MWP";
-        MarsRequest r = MarsRequest::parse(text);
-        auto params = r.values("param");
+        MarsRequest r=MarsRequest::parse(text);
+        auto params=r.values("param");
         EXPECT_EQUAL(params.size(), 2);
 
         EXPECT_EQUAL(params[0], "140252");
@@ -576,16 +621,16 @@ CASE( "test_metkit_expand_param" ) {
     }
     {
         const char* text = "retrieve,class=od,expver=1,stream=eefo,date=-1,time=0000,type=fcmean,levtype=sfc,step=24,param=MSL";
-        MarsRequest r = MarsRequest::parse(text);
-        auto params = r.values("param");
+        MarsRequest r=MarsRequest::parse(text);
+        auto params=r.values("param");
         EXPECT_EQUAL(params.size(), 1);
 
         EXPECT_EQUAL(params[0], "151");
     }
     {
         const char* text = "retrieve,class=od,expver=1,stream=eefo,date=-1,time=0000,type=fcmean,levtype=sfc,step=24,param=strda";
-        MarsRequest r = MarsRequest::parse(text);
-        auto params = r.values("param");
+        MarsRequest r=MarsRequest::parse(text);
+        auto params=r.values("param");
         EXPECT_EQUAL(params.size(), 1);
 
         EXPECT_EQUAL(params[0], "171175");
@@ -595,7 +640,7 @@ CASE( "test_metkit_expand_param" ) {
 CASE( "test_metkit_expand_d1" ) {
     {
         const char* text = "retrieve,class=d1,dataset=extremes-dt,date=-1";
-        std::map<std::string, std::vector<std::string>> expected{
+        ExpectedOutput expected{
                 {"class", {"d1"}},
                 {"dataset", {"extremes-dt"}},
                 {"expver", {"0001"}},
@@ -610,7 +655,7 @@ CASE( "test_metkit_expand_d1" ) {
         expand(text, "retrieve", expected, {-1});
     }    {
         const char* text = "retrieve,class=d1,dataset=extreme-dt,date=-1";
-        std::map<std::string, std::vector<std::string>> expected{
+        ExpectedOutput expected{
                 {"class", {"d1"}},
                 {"dataset", {"extremes-dt"}},
                 {"expver", {"0001"}},
@@ -626,7 +671,7 @@ CASE( "test_metkit_expand_d1" ) {
     }
     {
         const char* text = "retrieve,class=d1,dataset=climate-dt,levtype=pl,date=20000101,activity=CMIP6,experiment=hist,model=IFS-NEMO,generation=1,realization=1,resolution=high,stream=clte,type=fc,param=134/137";
-        std::map<std::string, std::vector<std::string>> expected{
+        ExpectedOutput expected{
                 {"class", {"d1"}},
                 {"dataset", {"climate-dt"}},
                 {"activity", {"cmip6"}},
@@ -644,10 +689,10 @@ CASE( "test_metkit_expand_d1" ) {
                 {"param", {"134","137"}}
             };
         expand(text, "retrieve", expected, {20000101});
-    }   
+    }
     {
         const char* text = "retrieve,date=20120515,time=0000,dataset=climate-dt,activity=cmip6,experiment=hist,generation=1,model=icon,realization=1,resolution=high,class=d1,expver=0001,type=fc,stream=clte,levelist=1,levtype=o3d,param=263500";
-        std::map<std::string, std::vector<std::string>> expected{
+        ExpectedOutput expected{
                 {"class", {"d1"}},
                 {"dataset", {"climate-dt"}},
                 {"activity", {"cmip6"}},
@@ -665,12 +710,12 @@ CASE( "test_metkit_expand_d1" ) {
                 {"param", {"263500"}}
             };
         expand(text, "retrieve", expected, {20120515});
-    }           
+    }
 }
 CASE( "test_metkit_expand_ng" ) {
     {
         const char* text = "retrieve,class=ng,date=20000101,activity=CMIP6,experiment=hist,model=IFS-NEMO,generation=1,realization=1,resolution=high,stream=clte,type=fc,levtype=pl,param=134/137";
-        std::map<std::string, std::vector<std::string>> expected {
+        ExpectedOutput expected {
                 {"class", {"ng"}},
                 {"levtype", {"pl"}},
                 {"levelist", {"1000","850","700","500","400","300"}},
@@ -691,6 +736,70 @@ CASE( "test_metkit_expand_ng" ) {
     }
 }
 
+CASE("test_metkit_expand_list") {
+  {
+    const char *text="list,date=20250105,domain=g,levtype=pl,expver="
+                       "0001,step=0,stream=oper,levelist=1000/850/700/500/400/"
+                       "300,time=1200,type=an,param=129";
+    ExpectedOutput expected{
+        {"class", {"od"}},
+        {"date", {"20250105"}},
+        {"domain", {"g"}},
+        {"levtype", {"pl"}},
+        {"levelist", {"1000", "850", "700", "500", "400", "300"}},
+        {"expver", {"0001"}},
+        {"time", {"1200"}},
+        {"stream", {"oper"}},
+        {"type", {"an"}},
+        {"param", {"129"}}};
+    expand(text, "list", expected, {20250105});
+  }
+  {
+    const char *text="list,class=tr,date=20250105";
+    ExpectedOutput expected{
+        {"class", {"tr"}}, {"date", {"20250105"}}};
+    expand(text, "list", expected, {20250105});
+  }
+}
+
+CASE("test_metkit_expand_read") {
+    {
+        const char* text = "read,class=tr,date=20250105,domain=g,levtype=pl,expver=0001,step=0,stream=oper,"
+                           "levelist=1000/850/700/500/400/300,time=1200,type=an,param=129";
+        ExpectedOutput expected {
+            {"class", {"tr"}},
+            {"date", {"20250105"}},
+            {"domain", {"g"}},
+            {"levtype", {"pl"}},
+            {"levelist", {"1000", "850", "700", "500", "400", "300"}},
+            {"expver", {"0001"}},
+            {"time", {"1200"}},
+            {"stream", {"oper"}},
+            {"type", {"an"}},
+            {"param", {"129"}}};
+        expand(text, "read", expected, {20250105});
+    }
+    {
+        const char* text = "read,date=20250105,param=129";
+        ExpectedOutput expected {{"date", {"20250105"}}, {"param", {"129"}}};
+        expand(text, "read", expected, {20250105});
+    }
+}
+
+CASE("test_metkit_expand_") {
+    {
+        const char* text = "retrieve,accuracy=16,area=60.0/-60.0/-60.0/60.0,class=ea,date=20101029,expver=1,grid=0.30/0.30,levelist=1/to/137,levtype=ml,number=-1,param=q/t/u/v/lnsp/z,rotation=0.0/0.0,step=000,stream=oper,time=15:00:00,type=an,target=\"reference.1OEDK0.data\"";
+        const char* expected = "CLASS=EA,TYPE=AN,STREAM=OPER, EXPVER=0001, LEVTYPE=ML, LEVELIST=1/2/3/4/5/6/7/8/9/10/11/12/13/14/15/16/17/18/19/20/21/22/23/24/25/26/27/28/29/30/31/32/33/34/35/36/37/38/39/40/41/42/43/44/45/46/47/48/49/50/51/52/53/54/55/56/57/58/59/60/61/62/63/64/65/66/67/68/69/70/71/72/73/74/75/76/77/78/79/80/81/82/83/84/85/86/87/88/89/90/91/92/93/94/95/96/97/98/99/100/101/102/103/104/105/106/107/108/109/110/111/112/113/114/115/116/117/118/119/120/121/122/123/124/125/126/127/128/129/130/131/132/133/134/135/136/137, PARAM=133/130/131/132/152/129, TIME=1500, STEP=000, DOMAIN=G, TARGET=reference.1OEDK0.data, RESOL=AUTO, ACCURACY=16, AREA=60/-60/-60/60, ROTATION=0.0/0.0, GRID=.3/.3";
+        expand(text, "retrieve", expected, {20101029});
+    }
+    {
+        const char* text = "retrieve,accuracy=10,class=ea,date=1969-03-28,expver=11,grid=0.25/0.25,levtype=sfc,packing=si,param=142.128/143.128/151.128/165.128/166.128,step=0/6/12/18/24/30/36/42/48/54/60/66/72/78/84/90/96/102/108/114/120/132/144/156/168/180/192/204/216/228/240,stream=oper,time=00:00:00,type=fc,target=\"reference.rFP7XB.data\"";
+        const char* expected = "CLASS      = EA,    TYPE       = FC,    STREAM     = OPER,    EXPVER     = 0011,     LEVTYPE    = SFC,    PARAM      = 142.128/143.128/151.128/165.128/166.128,    TIME       = 0000,    STEP       = 0/6/12/18/24/30/36/42/48/54/60/66/72/78/84/90/96/102/108/114/120/132/144/156/168/180/192/204/216/228/240,    DOMAIN     = G,    TARGET     = reference.rFP7XB.data,    RESOL      = AUTO,    ACCURACY   = 10,    GRID       = 0.25/0.25,    PACKING    = SIMPLE";
+        expand(text, "retrieve", expected, {19690328});
+    }
+    
+}
+
 //-----------------------------------------------------------------------------
 
 }  // namespace test
